==> ZZ-Source-Code-karing-1.2.4.869.zip: karing-1.2.4.869/README_cn.md <==
<h1 align="center">
  <img src="./README_assets/img/mascot.jpg" alt="Karing" width="256" />
  <br>
  Karing - 简单且强大的代理工具
  <br>
</h1>

<h3 align="center">
一个基于 <a href="https://github.com/flutter/flutter">flutter</a> 的 <a href="https://github.com/SagerNet/sing-box">singbox</a> 图形用户界面。
</h3>

[英语](./README.md) | 中文 | [俄语](./README_ru.md) | [波斯文](./README_fa.md)
### 注意: 
- **Karing未在任何视频平台开设过有关Karing的任何频道**
- **官方网站: https://karing.app**
## 特点
- 兼容 Clash、V2ray/V2fly、Sing-box、Shadowsocks、Sub、Github 订阅。
  - 完全支持 `clash` 配置，部分支持 `clash.meta` 配置。
- 一套路由规则应用于多个订阅源, 自动选择高效节点。
- 支持自定义路由规则组、节点组
  - 为小白用户定制默认路由规则组 - 开箱即用。
  - 内置 geo-ip、geo-site、acl等[规则集](https://github.com/KaringX/karing-ruleset/)
- 备份和同步, 一次配置多设备同步
  - 支持局域网内同步
  - 支持Webdav
  - 支持zip文件导入/导出
- 内置支持 [魔改版 singbox](https://github.com/KaringX/sing-box) 核心。
- 增加新手模式 配置更简单。
- 计划支持所有平台。

## 推广
<details>
<summary>查看所有推广



### ✈️推荐机场

[狗狗加速 —— 技术流机场 Doggygo VPN](https://1.x31415926.top/redir.html?url=aHR0cHM6Ly93d3cuZGc2LnRvcC8jL3JlZ2lzdGVyP2NvZGU9bEZINGlpOUQ=&i=3eb&t=1723644053)

- 高性能海外机场，海外团队，无跑路风险
- 专属链接注册送 3 天，每天 1G 流量 [免费试用](https://1.x31415926.top/redir.html?url=aHR0cHM6Ly93d3cuZGc2LnRvcC8jL3JlZ2lzdGVyP2NvZGU9bEZINGlpOUQ=&i=3eb&t=1723644053)
- 优惠套餐每月仅需 15.8 元，160G 流量，年付 8 折
- 全球首家支持`Hysteria2` 协议，集群负载均衡设计，高速专线，极低延迟，无视晚高峰，4K 秒开
- 解锁流媒体及 ChatGPT

[👉更多机场优惠 每日更新](https://1.x31415926.top/)

</summary>

### 🤝机场合作招募
- 👉[联系方式与合作形式](https://karing.app/blog/isp/cooperation)👈
</details>


## 系统要求
- Windows >= 10 （仅支持64位）
- Android >= 8  (arm64-v8a, armeabi-v7a)
- IOS >= 15
- MacOS >= 12
- TvOS >= 17

## 安装
- **IOS/MacOS/TvOS AppStore**: （搜索关键词：karing vpn）
  - https://apps.apple.com/us/app/karing/id6472431552
- **IOS/MacOS/TvOS TestFlight**:
  - https://testflight.apple.com/join/RLU59OsJ
- **Android**:
  - https://github.com/KaringX/karing/releases/latest
  - APKPure https://apkpure.com/p/com.nebula.karing
  - Amazon AppStore https://www.amazon.com/gp/product/B0DJSQDDM8
  - [gh-proxy of android backup](https://dot.karing.app/client.html?p=android)
- **Windows**:
  - https://github.com/KaringX/karing/releases/latest
  - [gh-proxy of win64 backup](https://dot.karing.app/client.html?p=windows)

### 常见问题

> [FAQ|cn](https://karing.app/en/faq/)

## 待办事项
- 待支持的平台：
  - Linux | [linglong](https://linglong.dev/)
- 全球化（多语言）
  - 如果您愿意与我们合作支持 Karing 全球化，请联系 [Telegram](https://t.me/ovowe)

## 截图（Windows 版本）

<div align="center">
  <img src="./README_assets/demo/home.png" alt="demo1" width="50%" />
  </br></br>
  <img src="./README_assets/demo/select_server.png" alt="demo2" width="50%" />
    </br></br>
  <img src="./README_assets/demo/connections.png" alt="demo3" width="50%" />
  </br></br>
  <img src="./README_assets/demo/setting.png" alt="demo4" width="50%" />
  </br></br>
  <img src="./README_assets/demo/routing_group.png" alt="demo5" width="50%" />
  </br></br>
  <img src="./README_assets/demo/add_profile_link.png" alt="demo6" width="50%" />
</div>

## 提交需求/bug
[欢迎报告问题！](https://github.com/KaringX/karing/issues)

## 捐赠
![donate](./README_assets/img/donate-usdt.jpg)

## Projects
### 致谢: Karing 基于或受到这些项目的启发：

- [flutter](https://flutter.dev/)：使构建美观应用变得轻松快捷。
- [singbox](https://sing-box.sagernet.org/)：通用代理平台。
- [Meta-Docs](https://wiki.metacubex.one/config/)：Clash.Meta 文档

### Karing Team:
- [Karing](https://karing.app): https://karing.app
- [Clash Mi](https://clashmi.app/): https://clashmi.app/
- [sing-poet](https://github.com/KaringX/sing-poet)

==> ZZ-Source-Code-karing-1.2.5.882.zip: karing-1.2.5.882/README_cn.md <==
<h1 align="center">
  <img src="./README_assets/img/mascot.jpg" alt="Karing" width="256" />
  <br>
  Karing - 简单且强大的代理工具
  <br>
</h1>

<h3 align="center">
一个基于 <a href="https://github.com/flutter/flutter">flutter</a> 的 <a href="https://github.com/SagerNet/sing-box">singbox</a> 图形用户界面。
</h3>

[英语](./README.md) | 中文 | [俄语](./README_ru.md) | [波斯文](./README_fa.md)
### 注意: 
- **Karing未在任何视频平台开设过有关Karing的任何频道**
- **官方网站: https://karing.app**
## 特点
- 兼容 Clash、V2ray/V2fly、Sing-box、Shadowsocks、Sub、Github 订阅。
  - 完全支持 `clash` 配置，部分支持 `clash.meta` 配置。
- 一套路由规则应用于多个订阅源, 自动选择高效节点。
- 支持自定义路由规则组、节点组
  - 为小白用户定制默认路由规则组 - 开箱即用。
  - 内置 geo-ip、geo-site、acl等[规则集](https://github.com/KaringX/karing-ruleset/)
- 备份和同步, 一次配置多设备同步
  - 支持局域网内同步
  - 支持Webdav
  - 支持zip文件导入/导出
- 内置支持 [魔改版 singbox](https://github.com/KaringX/sing-box) 核心。
- 增加新手模式 配置更简单。
- 计划支持所有平台。

## 推广
<details>
<summary>查看所有推广



### ✈️推荐机场

[狗狗加速 —— 技术流机场 Doggygo VPN](https://1.x31415926.top/redir.html?url=aHR0cHM6Ly93d3cuZGc2LnRvcC8jL3JlZ2lzdGVyP2NvZGU9bEZINGlpOUQ=&i=3eb&t=1723644053)

- 高性能海外机场，海外团队，无跑路风险
- 专属链接注册送 3 天，每天 1G 流量 [免费试用](https://1.x31415926.top/redir.html?url=aHR0cHM6Ly93d3cuZGc2LnRvcC8jL3JlZ2lzdGVyP2NvZGU9bEZINGlpOUQ=&i=3eb&t=1723644053)
- 优惠套餐每月仅需 15.8 元，160G 流量，年付 8 折
- 全球首家支持`Hysteria2` 协议，集群负载均衡设计，高速专线，极低延迟，无视晚高峰，4K 秒开
- 解锁流媒体及 ChatGPT

[👉更多机场优惠 每日更新](https://1.x31415926.top/)

</summary>

### 🤝机场合作招募
- 👉[联系方式与合作形式](https://karing.app/blog/isp/cooperation)👈
</details>


## 系统要求
- Windows >= 10 （仅支持64位）
- Android >= 8  (arm64-v8a, armeabi-v7a)
- Linux （仅支持64位）
- IOS >= 15
- MacOS >= 12 (Intel, Apple Silicon)
- TvOS >= 17

## 安装
- **IOS/TvOS AppStore**: （搜索关键词：karing vpn）
  - https://apps.apple.com/us/app/karing/id6472431552
- **IOS/TvOS TestFlight**:
  - https://testflight.apple.com/join/RLU59OsJ
- **Android**:
  - [https://karing.app/download](https://karing.app/download)
  - https://github.com/KaringX/karing/releases/latest
  - APKPure https://apkpure.com/p/com.nebula.karing
  - Amazon AppStore https://www.amazon.com/gp/product/B0DJSQDDM8
- **Windows/Macos/Linux**:
  - [https://karing.app/download](https://karing.app/download)
  - https://github.com/KaringX/karing/releases/latest


### 常见问题

> [FAQ|cn](https://karing.app/en/faq/)

## 待办事项
- 待支持的平台：
  - Linux | [linglong](https://linglong.dev/)
- 全球化（多语言）
  - 如果您愿意与我们合作支持 Karing 全球化，请联系 [Telegram](https://t.me/ovowe)

## 截图（Windows 版本）

<div align="center">
  <img src="./README_assets/demo/home.png" alt="demo1" width="50%" />
  </br></br>
  <img src="./README_assets/demo/select_server.png" alt="demo2" width="50%" />
    </br></br>
  <img src="./README_assets/demo/connections.png" alt="demo3" width="50%" />
  </br></br>
  <img src="./README_assets/demo/setting.png" alt="demo4" width="50%" />
  </br></br>
  <img src="./README_assets/demo/routing_group.png" alt="demo5" width="50%" />
  </br></br>
  <img src="./README_assets/demo/add_profile_link.png" alt="demo6" width="50%" />
</div>

## 提交需求/bug
[欢迎报告问题！](https://github.com/KaringX/karing/issues)

## 捐赠
![donate](./README_assets/img/donate-usdt.jpg)

## Projects
### 致谢: Karing 基于或受到这些项目的启发：

- [flutter](https://flutter.dev/)：使构建美观应用变得轻松快捷。
- [singbox](https://sing-box.sagernet.org/)：通用代理平台。
- [Meta-Docs](https://wiki.metacubex.one/config/)：Clash.Meta 文档

### Karing Team:
- [Karing](https://karing.app): https://karing.app
- [Clash Mi](https://clashmi.app/): https://clashmi.app/
- [sing-poet](https://github.com/KaringX/sing-poet)
